@@ -15,11 +15,15 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with versiontools.  If not, see <http://www.gnu.org/licenses/>.
+import sys
 
+from distutils.dist import Distribution
+from distutils.errors import DistutilsSetupError
 
 from unittest import TestCase
 
 from versiontools import Version
+from versiontools.setuptools_hooks import version as handle_version 
 
 
 class VersionFormattingTests(TestCase):
@@ -35,6 +39,18 @@ class VersionFormattingTests(TestCase):
     def test_defaults(self):
         self.assertEqual(Version(1, 0), (1, 0, 0, "final", 0))
 
+    def test_serial_cannot_be_zero_for_certain_releaselevel(self):
+        self.assertRaises(ValueError, Version, 1, 2, 3, "alpha", 0)
+        self.assertRaises(ValueError, Version, 1, 2, 3, "beta", 0)
+        self.assertRaises(ValueError, Version, 1, 2, 3, "candidate", 0)
+
+    def test_serial_can_be_zero_for_certain_releaselevel(self):
+        self.assertEqual(Version(1, 2, 3, "final", 0).serial, 0)
+        self.assertEqual(Version(1, 2, 3, "dev", 0).serial, 0)
+
+    def test_releaselevel_values(self):
+        self.assertRaises(ValueError, Version, 1, 2, 3, "foobar", 0)
+
     def test_accessors(self):
         version = Version(1, 2, 3, "dev", 4)
         self.assertEqual(version.major, 1)
@@ -104,3 +120,30 @@ class VersionFormattingTestsWithMockedVCS(TestCase):
         self.assertEqual(str(Version(1, 2, 3, "alpha", 4)), "1.2.3a4")
         self.assertEqual(str(Version(1, 2, 3, "beta", 4)), "1.2.3b4")
         self.assertEqual(str(Version(1, 2, 3, "candidate", 4)), "1.2.3c4")
+
+
+class HandleVersionTests(TestCase):
+
+    def setUp(self):
+        self.dist = Distribution()
+
+    def test_cant_import(self):
+        version = ':versiontools:nonexisting:'
+        try:
+            handle_version(self.dist, None, version)
+        except Exception:
+            e = sys.exc_info()[1]
+            self.assertTrue(isinstance(e, DistutilsSetupError))
+            self.assertEqual(str(e), "Unable to import 'nonexisting': "
+                                      "No module named nonexisting")
+
+    def test_not_found(self):
+        version = ':versiontools:versiontools:__nonexisting__'
+        try:
+            handle_version(self.dist, None, version)
+        except Exception:
+            e = sys.exc_info()[1]
+            self.assertTrue(isinstance(e, DistutilsSetupError))
+            self.assertEqual(str(e), "Unable to access '__nonexisting__' in "
+                                      "'versiontools': 'module' object has "
+                                      "no attribute '__nonexisting__'")
